# MOdule Reference by Analyzing the Syntax Tree

_Create reference documentation from sources using AST_

```
pip install morast
```

Installation in a virtual environment is strongly recommended.


## Usage

Output of `python3 -m morast --help`:

```
(tba)
```


## Further reading

Please see the documentation at <https://blackstream-x.gitlab.io/morast>
for detailed usage information.

If you found a bug or have a feature suggestion,
please open an issue [here](https://gitlab.com/blackstream-x/morast/-/issues)

